@@ -12,6 +12,13 @@ class LIB:
     def __init__(self):
         pass
 
+    @staticmethod
+    def token_get(word: str) -> str:
+        key = Fernet.generate_key()
+        f = Fernet(key)
+        token = f.encrypt(word.encode())
+        return token.decode()
+
     @staticmethod
     def findchar(string: str, substring: str, ocorrencia: int, inicio: int = 0, fim: int = None):
         if fim is None:
@@ -226,11 +233,15 @@ class LIB:
     @staticmethod
     def get_parametros_geral(conexao) -> pd.DataFrame:
         df = None
+        now = dt.datetime.now()
+        status = 'A' # Ativo
         try:
             sql = f"""
                    SELECT *
                      FROM Parametros
                     where flg_status = 'A'
+                      and to_date({now.astype(str)}, "%Y-%m-%d %H:%MM:%S") between dat_ini_vigencia and dat_fim_vigencia
+                      and flg_status = '{status}'
                     order by handle_parent, handle, num_ordem
                    """
             df = pd.read_sql(con=conexao, sql=sql)
@@ -325,5 +336,7 @@ class LIB:
         return cores
 
 if __name__ == "__main__":
-    pass
+    x = LIB()
+    t = x.token_get("D@S@")
+    print(t)
 
